#
#----------------------------------------
#
#
# 	Loren Williams, Georgia Tech
# 	pymol script for myoglobin 
#
#-----------------------------------------------------------------------------
## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# run the python program for hydrogen bonding interactions.
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0

#  run files/python/list_hbonds.py
#------put the python program list_hbonds.py
#------into the directory python.

## End of Header: General Commands ##
#-----------------------------------------------------------------------------

fetch 3QM5, myoglobin
fetch 3e5o, myoglobin_co

align myoglobin, myoglobin_co 

remove myoglobin and alt B
remove myoglobin and resi 156
h_add myoglobin
remove resn hoh

create Heme_O2, ( (resn HEM) or (resi 89) or (resi 202) ) and myoglobin 
distance FE_His = (heme_O2 and resn His and name NE2), (heme_O2 and name FE), 2.4
distance FE_O2 = (heme_O2 and resn OXY and name O2), (heme_O2 and name FE), 2.4

ou clicked /Heme_O2/C/A/OXY`202/O2`A

create Heme_CO, ( (resn HEM) or (resi 93) or (resi 157) ) and myoglobin_co 
create distal_his, resname his and resi 60 and myoglobin 
remove name H* and Heme_O2

create ribbon_myoglobin, myoglobin and chain A and not resn HEM
hide everything, ribbon_myoglobin
show cartoon, ribbon_myoglobin
set cartoon_fancy_helices, 0

---------render the heme groups
hide everything, Heme_*
show stick, Heme_O2
show spheres, heme_O2 and name FE
set sphere_scale, 0.3, heme_O2

show stick, heme_CO
show spheres, heme_CO and name FE
show spheres, heme_O2 and resn OXY
set sphere_scale, 0.3, heme_CO


##---------create helices
create Helix_A1, resi 2-9 and chain A and myoglobin
create Helix_A2, resi 11-16 and chain A and myoglobin
create Helix_B, resi 17-32 and chain A and myoglobin
create Helix_C, resi 34-38 and chain A and myoglobin
create Helix_D, resi 47-51 and chain A and myoglobin
create Helix_E, resi 54-73 and chain A and myoglobin
create Helix_F, resi 78-92 and chain A and myoglobin
create Helix_G, resi 97-115 and chain A and myoglobin
create Helix_H, resi 118-143 and chain A and myoglobin

create Helixr_A1, resi 2-9 and chain A and myoglobin
create Helixr_A2, resi 11-16 and chain A and myoglobin
create Helixr_B, resi 17-32 and chain A and myoglobin
create Helixr_C, resi 34-38 and chain A and myoglobin
create Helixr_D, resi 47-51 and chain A and myoglobin
create Helixr_E, resi 54-73 and chain A and myoglobin
create Helixr_F, resi 78-92 and chain A and myoglobin
create Helixr_G, resi 97-115 and chain A and myoglobin
create Helixr_H, resi 118-143 and chain A and myoglobin


hide everything, Helix_*
show cartoon, Helix_*
set cartoon_cylindrical_helices,1, Helix_*
set cartoon_helix_radius, 1.5

hide everything, Helixr_*
show cartoon, Helixr_*
set cartoon_oval_width, 4, Helixr_*

label Helix_A1 and resi 5+8 and name CB, " A1"
label Helix_A2 and resi 12+16 and name CA, " A2"
label Helix_B and resi 18+28 and name CA, " B"
label Helix_C and resi 34+38 and name CA, " C"
label Helix_D and resi 47+50 and name CA, " D"
label Helix_E and resi 59+66 and name CA, " E"
label Helix_F and resi 80+88 and name CA, " F"
label Helix_G and resi 100+111 and name CA, " G"
label Helix_H and resi 125+139 and name CA, " H"

color orange, name fe
color wheat, name C*
color paleyellow, name C* and his_*
color blue, name N*
color red, name O*

color cyan, ribbon_myoglobin
color magenta, ss 'h' and ribbon_myoglobin

color wheat, Helix_A*
set label_color, wheat, Helix_A*
color palegreen, Helix_B
set label_color, palegreen, Helix_B
color lightblue, Helix_C
set label_color, lightblue, Helix_C
color paleyellow, Helix_D
set label_color, paleyellow, Helix_D
color lightpink, Helix_E
set label_color, lightpink, Helix_E
color palecyan, Helix_F
set label_color, palecyan, Helix_F
color lightorange, Helix_G
set label_color, lightorange, Helix_G
color bluewhite, Helix_H
set label_color, bluewhite, Helix_H
set label_outline_color, black, Helix_*
set label_shadow_mode=2, Helix_*
set label_size, 30.0, Helix_*

color wheat, Helixr_A*
set label_color, wheat, Helix_A*
color palegreen, Helixr_B
set label_color, palegreen, Helix_B
color lightblue, Helixr_C
set label_color, lightblue, Helix_C
color paleyellow, Helixr_D
set label_color, paleyellow, Helix_D
color lightpink, Helixr_E
set label_color, lightpink, Helix_E
color palecyan, Helixr_F
set label_color, palecyan, Helix_F
color lightorange, Helixr_G
set label_color, lightorange, Helix_G
color bluewhite, Helixr_H
set label_color, bluewhite, Helixr_H
set label_outline_color, black, Helixr_*
set label_shadow_mode=2, Helixr_*
set label_size, 30.0, Helixr_*


create stick_myoglobin, myoglobin and chain A and not resn HEM
hide everything, stick_myoglobin
show stick, stick_myoglobin
remove not (name N+O+CA+C+CB) and stick_myoglobin
h_add stick_myoglobin and name N
alter (name H0*),name='H'

dist hbond_NH_O, (name O and stick_myoglobin), (name H and stick_myoglobin), 2.4 
#mode=2

color black, hbond_NH_O
set label_size, -0.30, hbond_NH_O
set dash_width, 3.0
set dash_gap, 0.30
set label_position, (1.2,0,0), hbond_NH_O

#-Planes------------------------------
python
import sys
sys.path.append('./files/')
from draw_plane_cgo import *

for i in range (3, 153):
	plnme = "plane" + str(i-3)
	st1= 'resi ' + str(i) + ' and name CA'
	st2= 'resi ' + str(i) + ' and name O'
	st3= 'resi ' + str(i+1) + ' and name H02'
	st4= 'resi ' + str(i+1) + ' and name CA'
	cmd.select("st1", st1)
	cmd.select("st2", st2)
	cmd.select("st3", st3)
	cmd.select("st4", st4)
	cstr = ''
	ccode = i%3
	if ccode == 1:
		cstr = "(255,0,255)"
	elif ccode == 2:
		cstr = "(255,255,0)"
	else:
		cstr = "(0,255,255)"

	draw_plane(plnme, "st1", "st2", "st3", "st4",cstr)
python end

delete st1
delete st2
delete st3
delete st4

#-------------------------------

### this set of commands will create an object (heme_pocket) containing
### the amino acids that are in contact with the heme 
### and will show it in surface representation
create heme_pocket, byres(ribbon_myoglobin within 3.5 of (Heme_O2 and not (resi 89 or resi 202)))
remove (heme_pocket within .1 of  Heme_O2)
color red, name O* and heme_pocket
color cyan, name C* and heme_pocket
color blue, name N* and heme_pocket
color yellow, name P* and heme_pocket
color yellow, name S* and heme_pocket
hide everything, heme_pocket
show surface, heme_pocket
set transparency, 0.4
#-------------------------------

label Heme_O2 and resn HIS and name CG, "Proximal His"
set label_size, 10.0, proximal_his

hide everything, distal_his
show stick, distal_his
show mesh, distal_his and (not name N+C+O+CA)
label distal_his and name CG, "Distal His"
label Heme_O2 and name FE, "Fe"
label Heme_O2 and resn OXY and name O2, "O2"
label Heme_CO and name CB and resn his, "Proximal His"


delete myoglobin
delete myoglobin_CO
disable all
enable ribbon_myoglobin
enable Heme_O2
enable Helix_*
enable FE_His
enable FE_O2
enable proximal_his
enable distal_his
set_view (\
    -0.667730868,   -0.012821966,    0.744281590,\
     0.530094087,   -0.710138381,    0.463343233,\
     0.522611916,    0.703935921,    0.480983466,\
     0.000000000,    0.000000000,  -34.776229858,\
     0.620629787,   -7.611006737,   14.672497749,\
    29.809982300,   39.742462158,  -20.000000000 )
### cut above here and paste into script ###